==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-greek.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PASTSURVEYS"," ");
define("_LVOTES"," ");
define("_TOTALVOTES"," ");
define("_VOTING","");
define("_OTHERPOLLS"," ");
define("_COMMENT","");
define("_NOCOMMENTS","  ");
define("_UCOMMENT","");
define("_CONFIGURE","");
define("_LOGINCREATE","  /  ");
define("_THRESHOLD","");
define("_NESTED","");
define("_FLAT","");
define("_THREAD","");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","    ");
define("_REFRESH","");
define("_REPLYMAIN"," ");
define("_COMMENTSWARNING","     .      .");
define("_NOSUBJECT"," ");
define("_SCORE"," ( )");
define("_USERINFO"," ");
define("_SENDAMSG"," ");
define("_READREST","    ...");
define("_REPLY"," ( )");
define("_NOANONCOMMENTS","        .     .");
define("_PARENT","");
define("_ROOT","");
define("_YOURNAME","");
define("_SUBJECT","");
define("_ALLOWEDHTML","   HTML");
define("_POSTANON"," ");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","  HTML");
define("_PLAINTEXT"," ");
define("_NOTRIGHT","          .         .");
define("_ONN","...");
define("_PREVIEW","");
define("_OK","Ok!");
define("_CURRENTPOLLRESULTS","  ");
define("_CURRENTSURVEY"," ");
define("_SURVEYCOM","-----");
define("_DIRECTCOM","-----");
define("_SURVEYCOMPRE","-----");
define("_SURVEYS","");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-greek.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PASTSURVEYS"," ");
define("_LVOTES"," ");
define("_TOTALVOTES"," ");
define("_VOTING","");
define("_OTHERPOLLS"," ");
define("_COMMENT","");
define("_NOCOMMENTS","  ");
define("_UCOMMENT","");
define("_CONFIGURE","");
define("_LOGINCREATE","  /  ");
define("_THRESHOLD","");
define("_NESTED","");
define("_FLAT","");
define("_THREAD","");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","    ");
define("_REFRESH","");
define("_REPLYMAIN"," ");
define("_COMMENTSWARNING","     .      .");
define("_NOSUBJECT"," ");
define("_SCORE"," ( )");
define("_USERINFO"," ");
define("_SENDAMSG"," ");
define("_READREST","    ...");
define("_REPLY"," ( )");
define("_NOANONCOMMENTS","        .     .");
define("_PARENT","");
define("_ROOT","");
define("_YOURNAME","");
define("_SUBJECT","");
define("_ALLOWEDHTML","   HTML");
define("_POSTANON"," ");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","  HTML");
define("_PLAINTEXT"," ");
define("_NOTRIGHT","          .         .");
define("_ONN","...");
define("_PREVIEW","");
define("_OK","Ok!");
define("_CURRENTPOLLRESULTS","  ");
define("_CURRENTSURVEY"," ");
define("_SURVEYCOM","-----");
define("_DIRECTCOM","-----");
define("_SURVEYCOMPRE","-----");
define("_SURVEYS","");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
